DROP TABLE ENTIDAD CASCADE CONSTRAINTS;

CREATE TABLE ENTIDAD (
       ENT_CLAVE            NUMBER(2) NOT NULL,
       ENT_DESCRIPCION      VARCHAR2(21) NOT NULL,
       PRIMARY KEY (ENT_CLAVE)
);


DROP TABLE DELEGACION CASCADE CONSTRAINTS;

CREATE TABLE DELEGACION (
       DEL_CLAVE            NUMBER(2) NOT NULL,
       DEL_DESCRIPCION      VARCHAR2(21) NOT NULL,
       PRIMARY KEY (DEL_CLAVE)
);


DROP TABLE ESCOLARIDAD CASCADE CONSTRAINTS;

CREATE TABLE ESCOLARIDAD (
       ESC_CLAVE            NUMBER(2) NOT NULL,
       ESC_DESCRIPCION      VARCHAR2(40) NOT NULL,
       PRIMARY KEY (ESC_CLAVE)
);


DROP TABLE ALUMNOS CASCADE CONSTRAINTS;

CREATE TABLE ALUMNOS (
       ALU_CLAVE            NUMBER(5) NOT NULL,
       ALU_NOMBRE           VARCHAR2(30) NOT NULL,
       ALU_APELLIDO_P       VARCHAR2(25) NOT NULL,
       ALU_APELLIDO_M       VARCHAR2(25) NOT NULL,
       ALU_LOGIN            VARCHAR2(9) NOT NULL,
       ALU_PASSWORD         VARCHAR2(8) NOT NULL,
       ALU_CALLEYNUMERO     VARCHAR2(50) NOT NULL,
       ALU_COLONIA          VARCHAR2(30) NOT NULL,
       ALU_TELEFONO         NUMBER(7) NULL,
       ALU_EMAIL            VARCHAR2(60) NULL,
       ESC_CLAVE            NUMBER(2) NULL,
       DEL_CLAVE            NUMBER(2) NULL,
       ENT_CLAVE            NUMBER(2) NULL,
       PRIMARY KEY (ALU_CLAVE), 
       FOREIGN KEY  (ENT_CLAVE)
               REFERENCES ENTIDAD, 
       FOREIGN KEY  (DEL_CLAVE)
               REFERENCES DELEGACION, 
       FOREIGN KEY  (ESC_CLAVE)
               REFERENCES ESCOLARIDAD
);


DROP TABLE PROFESORES CASCADE CONSTRAINTS;

CREATE TABLE PROFESORES (
       PRO_CLAVE            NUMBER(5) NOT NULL,
       PRO_NOMBRE           VARCHAR2(30) NULL,
       PRO_APELLIDO_P       VARCHAR2(25) NOT NULL,
       PRO_APELLIDO_M       VARCHAR2(25) NOT NULL,
       PRO_LOGIN            VARCHAR2(8) NOT NULL,
       PRO_PASSWORD         VARCHAR2(8) NOT NULL,
       PRO_ESPECIALIDAD     VARCHAR2(30) NOT NULL,
       PRO_CALLEYNUMERO     VARCHAR2(50) NOT NULL,
       PRO_COLONIA          VARCHAR2(30) NOT NULL,
       PRO_TELEFONO         NUMBER(7) NULL,
       PRO_EMAIL            VARCHAR2(60) NULL,
       ESC_CLAVE            NUMBER(2) NULL,
       DEL_CLAVE            NUMBER(2) NULL,
       ENT_CLAVE            NUMBER(2) NULL,
       PRIMARY KEY (PRO_CLAVE), 
       FOREIGN KEY  (ENT_CLAVE)
               REFERENCES ENTIDAD, 
       FOREIGN KEY  (DEL_CLAVE)
               REFERENCES DELEGACION, 
       FOREIGN KEY  (ESC_CLAVE)
               REFERENCES ESCOLARIDAD
);


DROP TABLE MATERIAS CASCADE CONSTRAINTS;

CREATE TABLE MATERIAS (
       MAT_CLAVE            NUMBER(5) NOT NULL,
       MAT_DESCRIPCION      VARCHAR2(30) NOT NULL,
       PRIMARY KEY (MAT_CLAVE)
);

DROP TABLE PLANTEL CASCADE CONSTRAINTS;

CREATE TABLE PLANTEL (
       PLA_CLAVE            NUMBER(5) NOT NULL,
       PLA_NOMBRE           VARCHAR2(80) NOT NULL,
       PLA_DIRECCION        VARCHAR2(50) NOT NULL,
       PRIMARY KEY (PLA_CLAVE)
);


DROP TABLE FACULTAD CASCADE CONSTRAINTS;

CREATE TABLE FACULTAD (
       PLA_CLAVE            NUMBER(5) NOT NULL,
       FAC_CLAVE            NUMBER(5) NOT NULL,
       FAC_NOMBRE           VARCHAR2(30) NOT NULL,
       PRIMARY KEY (PLA_CLAVE, FAC_CLAVE), 
       FOREIGN KEY  (PLA_CLAVE)
               REFERENCES PLANTEL
);


DROP TABLE CARRERA CASCADE CONSTRAINTS;
 CREATE TABLE CARRERA (
       PLA_CLAVE            NUMBER(5) NOT NULL,
       FAC_CLAVE            NUMBER(5) NOT NULL,
       CAR_CLAVE            NUMBER(5) NOT NULL,
       CAR_NOMBRE           VARCHAR2(40) NOT NULL,
       CAR_DURACION         NUMBER(2) NOT NULL,
       CAR_PLAN             VARCHAR2(50) NOT NULL,
       PRIMARY KEY (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE), 
       FOREIGN KEY  (PLA_CLAVE, FAC_CLAVE)
               REFERENCES FACULTAD
);


DROP TABLE GRUPO CASCADE CONSTRAINTS;

CREATE TABLE GRUPO (
       PLA_CLAVE            NUMBER(5) NOT NULL,
       FAC_CLAVE            NUMBER(5) NOT NULL,
       CAR_CLAVE            NUMBER(5) NOT NULL,
       GRU_CLAVE            NUMBER(5) NOT NULL,
       GRU_ANIO             NUMBER(4) NOT NULL,
       GRU_PERIODO          NUMBER(1) NOT NULL,
       GRU_SEMESTRE         NUMBER(2) NOT NULL,
       GRU_NOMBRE           VARCHAR2(20) NOT NULL,
       PRIMARY KEY (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, GRU_CLAVE),
       FOREIGN KEY  (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE)
               REFERENCES CARRERA
);


DROP TABLE ASIGNATURAS CASCADE CONSTRAINTS;

CREATE TABLE ASIGNATURAS (
       PLA_CLAVE            NUMBER(5) NOT NULL,
       FAC_CLAVE            NUMBER(5) NOT NULL,
       CAR_CLAVE            NUMBER(5) NOT NULL,
       MAT_CLAVE            NUMBER(5) NOT NULL,
       GRU_CLAVE            NUMBER(5) NOT NULL,
       PRO_CLAVE            NUMBER(5) NOT NULL,
       PRIMARY KEY (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE,MAT_CLAVE, GRU_CLAVE),
       FOREIGN KEY  (PRO_CLAVE)
               REFERENCES PROFESORES, 
       FOREIGN KEY  (MAT_CLAVE)
               REFERENCES MATERIAS, 
       FOREIGN KEY  (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, GRU_CLAVE)
               REFERENCES GRUPO
);


DROP TABLE LISTA CASCADE CONSTRAINTS;

CREATE TABLE LISTA (
       PLA_CLAVE            NUMBER(5) NOT NULL,
       FAC_CLAVE            NUMBER(5) NOT NULL,
       CAR_CLAVE            NUMBER(5) NOT NULL,
       MAT_CLAVE            NUMBER(5) NOT NULL,
       GRU_CLAVE            NUMBER(5) NOT NULL,
       ALU_CLAVE            NUMBER(5) NOT NULL,
       LIS_CONSECUTIVO      CHAR(18) NULL,
       LIS_PROMEDIO         DECIMAL(3,2) NULL,
       PRIMARY KEY (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE,ALU_CLAVE),
       FOREIGN KEY  (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE)
               REFERENCES ASIGNATURAS, 
       FOREIGN KEY  (ALU_CLAVE)
               REFERENCES ALUMNOS
);


DROP TABLE EXAMEN CASCADE CONSTRAINTS;

CREATE TABLE EXAMEN (
       PLA_CLAVE            NUMBER(5) NOT NULL,
       FAC_CLAVE            NUMBER(5) NOT NULL,
       CAR_CLAVE            NUMBER(5) NOT NULL,
       MAT_CLAVE            NUMBER(5) NOT NULL,
       GRU_CLAVE            NUMBER(5) NOT NULL,
       EXA_CLAVE            NUMBER(5) NOT NULL,
       EXA_DESCRIPCION      VARCHAR2(40) NOT NULL, 
       PRIMARY KEY (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE,EXA_CLAVE),
       FOREIGN KEY  (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE)
               REFERENCES ASIGNATURAS
);


DROP TABLE EVALUACIONES CASCADE CONSTRAINTS;

CREATE TABLE EVALUACIONES (
       PLA_CLAVE            NUMBER(5) NOT NULL,
       FAC_CLAVE            NUMBER(5) NOT NULL,
       CAR_CLAVE            NUMBER(5) NOT NULL,
       MAT_CLAVE            NUMBER(5) NOT NULL,
       GRU_CLAVE            NUMBER(5) NOT NULL,
       ALU_CLAVE            NUMBER(5) NOT NULL,
       EXA_CLAVE            NUMBER(5) NOT NULL,
       EVA_CLAVE            NUMBER(5) NOT NULL,
       EVA_CALIFICACION     DECIMAL(6,2) NOT NULL,
       PRIMARY KEY (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE,ALU_CLAVE, EXA_CLAVE, EVA_CLAVE),
       FOREIGN KEY  (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE,ALU_CLAVE)
               REFERENCES LISTA, 
       FOREIGN KEY  (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE,EXA_CLAVE)
               REFERENCES EXAMEN
);


DROP TABLE PREGUNTAEXAMEN CASCADE CONSTRAINTS;

CREATE TABLE PREGUNTAEXAMEN (
       PLA_CLAVE            NUMBER(5) NOT NULL,
       FAC_CLAVE            NUMBER(5) NOT NULL,
       CAR_CLAVE            NUMBER(5) NOT NULL,
       MAT_CLAVE            NUMBER(5) NOT NULL,
       GRU_CLAVE            NUMBER(5) NOT NULL,
       EXA_CLAVE            NUMBER(5) NOT NULL,
       PRE_EXA_CLAVE        NUMBER(5) NOT NULL,
       PRE_EXA_DESCRIPCION  VARCHAR2(250) NOT NULL,
       PRIMARY KEY (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE,EXA_CLAVE, PRE_EXA_CLAVE),
       FOREIGN KEY  (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE,EXA_CLAVE)
               REFERENCES EXAMEN
);


DROP TABLE HOJA_RESPUESTA_EXAMEN CASCADE CONSTRAINTS;

CREATE TABLE HOJA_RESPUESTA_EXAMEN (
       PLA_CLAVE            NUMBER(5) NOT NULL,
       FAC_CLAVE            NUMBER(5) NOT NULL,
       CAR_CLAVE            NUMBER(5) NOT NULL,
       MAT_CLAVE            NUMBER(5) NOT NULL,
       GRU_CLAVE            NUMBER(5) NOT NULL,
       ALU_CLAVE            NUMBER(5) NOT NULL,
       EXA_CLAVE            NUMBER(5) NOT NULL,
       EVA_CLAVE            NUMBER(5) NOT NULL,
       PRE_EXA_CLAVE        NUMBER(5) NOT NULL,
       RES_ALUMNO           NUMBER(5) NOT NULL, 
       PRIMARY KEY (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE,ALU_CLAVE, EXA_CLAVE, EVA_CLAVE, PRE_EXA_CLAVE),
       FOREIGN KEY  (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE,ALU_CLAVE, EXA_CLAVE, EVA_CLAVE)
               REFERENCES EVALUACIONES, 
       FOREIGN KEY  (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE,EXA_CLAVE,PRE_EXA_CLAVE)
               REFERENCES PREGUNTAEXAMEN
);


DROP TABLE RESPUESTAEXAMEN CASCADE CONSTRAINTS;

CREATE TABLE RESPUESTAEXAMEN (
       PLA_CLAVE            NUMBER(5) NOT NULL,
       FAC_CLAVE            NUMBER(5) NOT NULL,
       CAR_CLAVE            NUMBER(5) NOT NULL,
       MAT_CLAVE            NUMBER(5) NOT NULL,
       GRU_CLAVE            NUMBER(5) NOT NULL,
       EXA_CLAVE            NUMBER(5) NOT NULL,
       PRE_EXA_CLAVE        NUMBER(5) NOT NULL,
       RES_EXA_CLAVE        NUMBER(5) NOT NULL,
       RES_EXA_DESCRIPCION  VARCHAR2(250) NOT NULL,
       RES_EXA_VALOR        DECIMAL(3,2) NOT NULL,
       PRIMARY KEY (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE,EXA_CLAVE, PRE_EXA_CLAVE, RES_EXA_CLAVE),
       FOREIGN KEY  (PLA_CLAVE, FAC_CLAVE, CAR_CLAVE, MAT_CLAVE, GRU_CLAVE,EXA_CLAVE, PRE_EXA_CLAVE)
               REFERENCES PREGUNTAEXAMEN
);


CREATE TABLE ADMINISTRADOR (
       ADM_CLAVE            NUMBER(5) NOT NULL,
       ADM_NOMBRE           VARCHAR2(30) NULL,
       ADM_APELLIDO_P       VARCHAR2(25) NOT NULL,
       ADM_APELLIDO_M       VARCHAR2(25) NOT NULL,
       ADM_LOGIN	    VARCHAR2(8) NOT NULL,
       ADM_PASSWORD         VARCHAR2(8) NOT NULL,
       PRIMARY KEY (ADM_CLAVE));

